flask-oidc
==========

`OpenID Connect <https://openid.net/connect/>`_ support for `Flask <http://flask.pocoo.org/>`_.

.. image:: https://img.shields.io/pypi/v/flask-oidc.svg?style=flat
  :target: https://pypi.python.org/pypi/flask-oidc

.. image:: https://img.shields.io/pypi/dm/flask-oidc.svg?style=flat
  :target: https://pypi.python.org/pypi/flask-oidc

.. image:: https://readthedocs.org/projects/flask-oidc/badge/?version=latest
   :target: http://flask-oidc.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/travis/puiterwijk/flask-oidc.svg?style=flat
  :target: https://travis-ci.org/puiterwijk/flask-oidc

This library should work with any standards compliant OpenID Connect provider.

It has been tested with:

* `Google+ Login <https://developers.google.com/accounts/docs/OAuth2Login>`_
* `Ipsilon <https://ipsilon-project.org/>`_


Project status
==============

This project is in active development.
